REM  Command file to automatically generate a Plane Plotter Mode-S
REM  report for yesterday, and e-mail it to your recipients.

REM  Revision history
REM  2011-Jul-26  V1.0.0  First released version
REM  2011-Jul-28  V1.0.1  Minor text changes
REM  2011-Jul-28  V1.0.2  Simplify the default log files location
REM  2011-Jul-31  V1.0.3  Slight text changes
REM  2011-Aug-03  V1.0.4  Clarify BLAT subject parameter
REM  2011-Aug-03  V1.0.5  Add some simple error checking
REM                       Add missing trailing backslash to PPLOGS
REM  2011-Aug-06  V1.0.6  Updates after suggestions from Dick at Apeldoorn
REM  2011-Aug-25  V1.0.7  Remove "format could change" text
REM  2012-Feb-20  V2.0.0  More user-friendly format
REM                       Splits Hex/Callsign/Reg into separate fields
REM  2012-May-29  V2.1.0  Update for Plane Plotter 6.2.6.5, report name changed
REM                         from pp_report20120527.sqb
REM                         to pp_report2012052800.sqb
REM  2013-Feb-27  V2.1.1  Add example of multiple e-mail recipients
REM  2014-Jan-28  V2.2.0  Add option for first and last time
REM  2016-Oct-03  V2.2.1  Make date more user-friendly


REM  Usage:
REM  I suggest you run this by hand for the first few times, and once
REM  you are happy, schedule the command-file to run perhaps some 
REM  minutes after midnight /UTC/.  This means scheduling after 01:00
REM  in the UK or after 02:00 in Western Europe.  Use 03:23 to be safe!

REM  SQLIte3.exe is from: http://www.sqlite.org/download.html
REM  BLAT.exe is from http://sourceforge.net/projects/blat/files/
REM  Other programs from: http://www.satsignal.eu/

REM  Point PPLOGS to the location where your pp_report*.sqb live
REM  Be sure to include the trailing backslash

set PPLOGS=C:\Tools\COAA\PlanePlotter\LogFiles\

REM  Uncomment the line below to include both first and last times

REM  set PPReportBothTimes=Y

REM  I have Plane Plotter running on a different PC, so I copy the log files 
REM  from that PC to my local one.  You will likely not need to do this.
REM  Uncomment the following line only if needed.

REM  robocopy \\<PC-name>\<share>\PlanePlotterlogFiles  "C:\Tools\COAA\PlanePlotter\LogFiles"  pp_report*.sqb

REM  Set the environment variable YESTERDAY etc. to the UTC date string for yesterday.

set YESTERDAY=
REM PP before 6.2.6.5  for /f "tokens=*" %%i in ('GetYesterday') do set YESTERDAY=%%i
for /f "tokens=*" %%i in ('GetYesterday') do set YESTERDAY=%%i00

@ECHO Processing: %yesterday%
IF NOT EXIST "%PPLOGS%pp_report%YESTERDAY%.sqb" (
  @ECHO File "%PPLOGS%pp_report%YESTERDAY%.sqb" is missing
  PAUSE
  GOTO :EOF
)

REM Crate a user-friendly date from PP string
SET REPDATE=%YESTERDAY:~0,4%/%YESTERDAY:~4,2%/%YESTERDAY:~6,2%

REM  These lines are added to the start of the report.  The first line 
REM  has a ">" in the echo command to start the file, and sunsequent lines
REM  use the ">>" so that the text lines are appended.

ECHO Plane Plotter with the Beast report from David Taylor, Edinburgh %REPDATE% > pp-report-%YESTERDAY%.txt
ECHO. >> pp-report-%YESTERDAY%.txt
ECHO Created with David Taylor's report toolkit V2.2.1>> pp-report-%YESTERDAY%.txt
ECHO .. download: http://www.satsignal.eu/software/MakePlanePlotterReport.zip>> pp-report-%YESTERDAY%.txt
ECHO .. support: http://groups.yahoo.com/group/DavidTaylorsSoftware>> pp-report-%YESTERDAY%.txt
ECHO. >> pp-report-%YESTERDAY%.txt
ECHO Times are UTC>> pp-report-%YESTERDAY%.txt
ECHO. >> pp-report-%YESTERDAY%.txt
ECHO Hex    Callsign   Reg     Type       Route        FAlt    Lalt   Fsqk  Lsqk  Date/Time (dd/mm/yyyy)>> pp-report-%YESTERDAY%.txt
ECHO. >> pp-report-%YESTERDAY%.txt

REM  Now run the program to extract the text from the Daily Database, and
REM  append the program's output to the text file we are building.

sqlite3.exe "%PPLOGS%pp_report%YESTERDAY%.sqb" < sql_commands.txt >> pp-report-%YESTERDAY%.txt

REM  Run the program which replaces UNIX-style times with human ones.

SplitFields.exe  pp-report-%YESTERDAY%.txt

REM  Use TrimTree to restrict the number of daily files.
REM  Here I set for 30 days worth of data.
REM  Uncomment these commands (remove the REM) to enable file trimming

REM  TrimTree 30 "%PPLOGS%" pp_report*.sqb  -MIN
REM  TrimTree 5 . pp-report-*.txt  -MIN

REM  When first running, leave the line below in place so that you can test
REM  the production of the data file before e-mailing it!  Once you are
REM  happy with the file, put a REM in front of the GOTO to comment it out.

PAUSE
GOTO :EOF

REM  Use BLAT to e-mail the report.  The "-to" can contain a comma-separated
REM  list of recipients.  You will need to substitute your own e-mail details
REM  for the dummy values here.  The carets "^" at the end of the lines are
REM  DOS line-continuation characters.
REM  "-s" is the subject - please keep the subject without spaces!
REM  For more information on the parameters to BLAT please see:
REM    http://www.blat.net/syntax/syntax.html

blat pp-report-%YESTERDAY%.txt		^
  -to Mode_S@yahoogroups.com, my-e-mail-user-id@my-isp.co.uk		^
  -s PP-log-report-from-Edinburgh-%REPDATE%	^
  -f my-e-mail-user-id@my-isp.co.uk	^
  -server smtp.my-isp.co.uk		^
  -pu my-e-mail-user-id@my-isp.co.uk	^
  -ppw my-password

REM  Example of using mailsend for Google mail
REM  mailsend is here: https://github.com/muquit/mailsend/releases

mailsend ^
  -to a-group@googlegroups.com,another-group@googlegroups.com ^
  -from your-user-ID@gmail.com ^
  -smtp smtp.gmail.com ^
  -ssl -port 465 -auth-plain ^
  -user your-user-ID@gmail.com -pass your-password ^
  -sub PP-log-report-from-Edinburgh-%REPDATE% ^
  -mime-type "text/plain" ^
  -msg-body "pp-report-%YESTERDAY%.txt" 

